:host {
  display: block;
}

.container {
  display: flex;
  border-radius: 12px;
  overflow: hidden;
  border: 1px solid var(--vp-c-border, #e5e7eb);
  background: var(--vp-c-bg, #ffffff);
}

.docs-pane {
  width: 40%;
  min-width: 300px;
  max-width: 500px;
  border-right: 1px solid var(--vp-c-border, #e5e7eb);
  background: var(--vp-c-bg-soft, #f9f9f9);
}

.terminal-pane {
  flex: 1;
  position: relative;
  min-width: 400px;
  display: flex;
  flex-direction: column;
}

.terminal-loading {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  background: #1a1a1a;
  color: #d4d4d4;
  gap: 12px;
  z-index: 10;
  border-radius: 0 0 11px 0;
}

.spinner {
  width: 24px;
  height: 24px;
  border: 3px solid #333;
  border-top-color: var(--skillet-primary, #8B7355);
  border-radius: 50%;
  animation: spin 1s linear infinite;
}

@keyframes spin {
  to { transform: rotate(360deg); }
}
